<?php
namespace Teknisa\DF\Controllers;

use Teknisa\DF\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\DF\Services\InventarioRotativoService;

class Ger03302Inverota extends TeknisaCrud{
    protected $dataSourceNames = array('utiliza' =>'inverota_lote','naoUtiliza'=>'inverota_sem_lote' );
    protected $parameterBagColumns = array("CDFILIAL", "DTINVEROTA", "CDALMOXARIFE","CDLOCALESTOQ");
    protected $dataSourceName;
    protected $inverotaService;

    public function __construct($crudService,$parameterBag, InventarioRotativoService $inverotaService) {
        parent::__construct($crudService,$parameterBag);
        $this->inverotaService = $inverotaService;
    }

    public function find(Filter $request,Response $response){

        $filter = $request->getFilterCriteria()->getConditions();
        $utAlmox = false;
        foreach($filter as $index => $property){
            if($property['columnName'] == 'UTLOTE'){
                $utAlmox = $property['value'];
                unset($filter[$index]);
            }
        }
        $this->dataSourceName = $utAlmox ? $this->dataSourceNames['utiliza'] : $this->dataSourceNames['naoUtiliza'];

        $filterCriteria = new FilterCriteria($this->dataSourceName,$filter);
        $newRequest = new Filter($filterCriteria,$request->getMethod(),$request->getRoutePath(),$request->getUserId());


        parent::find($newRequest,$response);
    }

    public function atualizaInventarioRotativo(Filter $request,Response $response){
        $filter = $request->getFilterCriteria()->getConditions();
        foreach ($filter as $field) {
            if($field['columnName'] == 'EVOLESTOQ')
                $evolestoq=$field['value'];
            if($field['columnName'] == 'CDFILIMOVI')
                $cdfilimovi=$field['value'];
            if($field['columnName'] == 'CDFILIAL')
                $cdfilial=$field['value'];
            if($field['columnName'] == 'CDOPERADOR')
                $cdoperador=$field['value'];
            if($field['columnName'] == 'DTPROCESSA')
                $dtprocessa=$field['value'];
            if($field['columnName'] == 'INOPCAO')
                $inopcao=$field['value'];
            if($field['columnName'] == 'CDSERVFILI')
                $cdservfili=$field['value'];
            if($field['columnName'] == 'CDTIPORET')
                $cdtiporet=$field['value'];
            if($field['columnName'] == 'CDCENTCUST')
                $cdcentcust=$field['value'];
            if($field['columnName'] == 'CDSETOR')
                $cdsetor=$field['value'];
            if($field['columnName'] == 'RETIESTQ')
                $retiestq=$field['value'];
            if($field['columnName'] == 'CDALMOXARIFE')
                $cdalmoxarife=$field['value'];
            if($field['columnName'] == 'CDLOCALESTOQ')
                $cdlocalestoq=$field['value'];
        }
        $this->inverotaService->executaProcedureAjuteZeraInve($evolestoq, $cdfilimovi, $cdfilial, $cdoperador, $dtprocessa, $inopcao, $cdservfili, $cdtiporet, $cdcentcust, $cdsetor, $retiestq, $cdalmoxarife, $cdlocalestoq);
        $isValid = $this->inverotaService->validateInventarioRotativo($cdfilial);
        $response->addDataSet(new DataSet('AtualizaInveRota', [$isValid]));

    }
    
    public function validateInventarioRotativo(Request $request,Response $response){
        $row = $request->getRow();
        $isValid = $this->inverotaService->validateInventarioRotativo($row['CDFILIAL']);
        $response->addDataSet(new DataSet('AtualizaInveRota', [$isValid]));
    }
}