<?php

namespace Teknisa\DF\Modules\Entrada\Factories;

use Doctrine\ORM\EntityManager;
    
class EntradasOperadorLogisticoFactory {

    const GERA_CORPO_NOTA_ENTRADA = "GERA_NOTAFISCAL_CORPO_ENTRADA";

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getParamsGeracao($cdFilial) {
        $sql = "SELECT F.CDSERIE,
                 F.CDEMPRESA,
                 F.CDINSCESTA,
                 PF.CDTIPCUSTEST,
                 PE.IDLANCDTMAI,
                 PE.IDLANCDTMEN,
                 PF.IDLANCDTMENFIL,
                 PF.NRDIASENTRFIL,
                 PF.DTPROCESSA AS DTPROCESSAFILI,
                 PF.IDUTCTRLFISSAID AS IDUTCTRLFISSAIDPF,
                 PF.IDUTCTRLFISENTR AS IDUTCTRLFISENTRPF,
                 PG.IDUTCTRLFISENTR AS IDUTCTRLFISENTRPG,
                 PG.IDUTCTRLFISSAID AS IDUTCTRLFISSAIDPG,
                 PG.IDUTORIGPROD,
                 NVL(PG.IDBLOQLANCNFOPFIL, 'N') AS IDBLOQLANCNFOPFIL,
                 F.CDFILIAL,
                 PE.NRDIASENTR,
                 (CASE PG.IDUTILDTPROC
            WHEN 'N' THEN
            SYSDATE
            ELSE DTPROCESSA END) DTPROCESSA, PF.IDLANCDTMAIFIL, PF.NRDIASENTRPDFIL, PE.NRDIASENTRPD
        FROM 
            (SELECT :P_CDFILIAL AS CDFILIAL,
                 NVL(IDUTILDTPROC,
                 'N') IDUTILDTPROC,
                 IDUTCTRLFISSAID,
                 IDUTCTRLFISENTR,
                 IDBLOQLANCNFOPFIL,
                 IDUTORIGPROD
            FROM PARAMGERAL PG) PG, 
            (SELECT PF.CDFILIAL,
                 NVL(PF.DTPROCESSA,
                 SYSDATE) DTPROCESSA,
                 PF.IDLANCDTMENFIL,
                 PF.NRDIASENTRFIL,
                 PF.IDLANCDTMAIFIL,
                 PF.NRDIASENTRPDFIL,
                 PF.IDUTCTRLFISENTR,
                 PF.IDUTCTRLFISSAID,
                 NVL(PF.CDTIPCUSTEST,
                 '3') AS CDTIPCUSTEST
            FROM PARAMFILIAL PF
            WHERE PF.CDFILIAL = :P_CDFILIAL) PF, 
            (SELECT :P_CDFILIAL AS CDFILIAL,
                 PE.IDLANCDTMAI,
                 PE.IDLANCDTMEN,
                 PE.NRDIASENTR,
                 PE.NRDIASENTRPD
            FROM PARAMESTOQUE PE) PE, FILIAL F
        WHERE PG.CDFILIAL = PF.CDFILIAL(+)
                AND PG.CDFILIAL = PE.CDFILIAL(+)
                AND PG.CDFILIAL = F.CDFILIAL";

        $params = array("P_CDFILIAL" => $cdFilial);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0];
    }
    
    public function getParamSupri($cdFilial) {
        $sql = "SELECT PARASUPRI.IDUTCTRLFISOL,
                  PARAMFILIAL.IDUTCTRLFIS
                FROM PARASUPRI,
                  FILIAL,
                  PARAMFILIAL
                WHERE PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                AND FILIAL.CDFILIAL      = :P_CDFILIAL
                AND PARAMFILIAL.CDFILIAL = FILIAL.CDFILIAL";

        $params = array("P_CDFILIAL" => $cdFilial);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0];
    }
    
    public function getTipoOperOpl($cdFiliOperLog, $cdFilial) {
        $sql = "SELECT TIPOOPEROPL.CDTIPOOPERSAID, TIPOOPEROPL.CDTIPOOPERENTR
            FROM TIPOOPEROPL
           WHERE TIPOOPEROPL.CDFILIOPELOG  =  :P_CDFILIOPELOG
             AND TIPOOPEROPL.CDFILDEST     = :P_CDFILIAL
             AND TIPOOPEROPL.CDTIPOOPERSAID IS NOT NULL
             AND TIPOOPEROPL.CDTIPOOPERENTR IS NOT NULL";
             
        $params = array("P_CDFILIOPELOG" => $cdFiliOperLog, "P_CDFILIAL" => $cdFilial);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getDataEmbarqueOl($cdFiliDest, $cdFiliOperLog, $nrLanctonf) {
        $sql = "SELECT MAX(NRDIAEMBARQUE) NRDIAEMBARQUE
                FROM DATAEMBARQUEOL,
                  PRODUTO PRODEMBARQUE,
                  ITEMPRODUTO,
                  RELACPRODOL,
                  PRODUTO PRODITEM
                WHERE DATAEMBARQUEOL.CDPRODUTO  = PRODEMBARQUE.CDPRODUTO
                AND DATAEMBARQUEOL.CDFILIAL     = :P_CDFILDEST
                AND DATAEMBARQUEOL.CDFILIOPELOG = :P_CDFILIOPELOG
                AND ITEMPRODUTO.CDFILIAL        = :P_CDFILIOPELOG
                AND ITEMPRODUTO.NRLANCTONF      = :P_NRLANCTONF
                AND ITEMPRODUTO.CDPRODUTO       = RELACPRODOL.CDPRODARVOL
                AND RELACPRODOL.CDPRARVORIG     = PRODITEM.CDPRODUTO
                AND PRODEMBARQUE.CDARVPROD      =
                  (SELECT MAX(CDARVPROD)
                  FROM DATAEMBARQUEOL A,
                    PRODUTO B
                  WHERE A.CDFILIAL                           = :P_CDFILDEST
                  AND A.CDFILIOPELOG                         = :P_CDFILIOPELOG
                  AND A.CDPRODUTO                            = B.CDPRODUTO
                  AND INSTR(PRODITEM.CDARVPROD, B.CDARVPROD) = 1
                  )";
                  
        $params = array("P_CDFILIOPELOG" => $cdFiliOperLog, "P_CDFILDEST" => $cdFiliDest, "P_NRLANCTONF" => $nrLanctonf);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getFeriFeli($data, $cdFilial) {
        $sql = "SELECT DTFERIFILI
              FROM FERIFILI
              WHERE DTFERIFILI = :P_DATA
                AND CDFILIAL   = :P_CDFILIAL";
                
        $params = array("P_DATA" => $data, "P_CDFILIAL" => $cdFilial);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public function getContopectbl($cdEmpresa) {
        $sql = "SELECT DTINIINTCONTDFE,
                  DTFININTCONTDFE,
                  DTINIINTCONTDFS,
                  DTFININTCONTDFS
                FROM CONTOPECTBL
                WHERE (CDEMPRESA = :P_CDEMPRESA)";
                
        $params = array("P_CDEMPRESA" => $cdEmpresa);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    
    public function getNotaFiscal($cdFiliRece, $cdFiliEmit, $nrNotaFisc) {
        $sql = "SELECT CDFILIAL, NRLANCTONF
                  FROM NOTAFISCAL
                  WHERE CDFILIRECE = :P_CDFILIRECE
                    AND CDFILIEMIT = :P_CDFILIEMIT
                    AND IDENTRSAIDOP = 'E'
                    AND NRNOTAFISC = :P_NRNOTAFISC";
                    
        $params = array("P_CDFILIRECE" => $cdFiliRece, "P_CDFILIEMIT" => $cdFiliEmit, "P_NRNOTAFISC" => $nrNotaFisc);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function buscaProdutosOrigem($cdFilial, $nrLanctonf, $cdFildest, $tipocusto, $dtProc, $idutorigprod) {
        $sql = "SELECT CDPRODUTO,
                  CDARVPROD,
                  NMPRODUTO,
                  SUM(NVL(QTSAIDOPLOG,0)) AS QTSAIDOPLOG,
                  SUM(QTPROGENTAF)        AS QTPROGENTAF,
                  VRPREUNIAF,
                  SUM(QTNFRELAFSAI) AS QTNFRELAFSAI,
                  CDFILLANC,
                  CDFILDEST,
                  NRAUTOFORN,
                  CDMARCA,
                  DTPROGENTAF,
                  VRUNITITEM,
                  ROUND(SUM(QTNFRELAFSAI) * VRUNITITEM,2) AS VRTOTAITEM,
                  IDUTILITEM,
                  NRSEQITPROD,
                  IDORIGEMPROD
                FROM
                  (SELECT N.CDPRODUTO,
                    P.CDARVPROD,
                    P.NMPRODUTO,
                    I.QTSAIDOPLOG,
                    I.QTPROGENTAF,
                    I.VRPREUNIAF,
                    N.QTNFRELAFSAI,
                    I.CDFILLANC,
                    I.CDFILDEST,
                    I.NRAUTOFORN,
                    I.CDMARCA,
                    I.DTPROGENTAF,
                    OP.VRUNITITEM,
                    ''  AS VRTOTAITEM,
                    '1' AS IDUTILITEM,
                    OP.NRSEQITPROD,
                    OP.IDORIGEMPROD
                  FROM NFRELACAFSAI N,
                    ITEMAUTF I,
                    PRODUTO P,
                    (SELECT R.CDPRARVORIG,
                      R.CDMARCA,
                      SUM(I.QTITEMPROD*I.VRUNITITEM) / SUM(I.QTITEMPROD*(D.VRFATUNEST/C.VRFATUNEST)) AS VRUNITITEM,
                      I.NRSEQITPROD,
                      I.IDORIGEMPROD
                    FROM ITEMPRODUTO I,
                      RELACPRODOL R,
                      CNVPRODUNEST C,
                      CNVPRODUNEST D
                    WHERE I.CDFILIAL  = :P_CDFILIAL
                    AND I.NRLANCTONF  = :P_NRLANCTONF
                    AND I.CDPRODUTO   = D.CDPRUNEST
                    AND D.CDPRODUTO   = C.CDPRODUTO
                    AND R.CDPRODARVOL = C.CDPRUNEST
                    GROUP BY R.CDPRARVORIG,
                      R.CDMARCA,
                      I.NRSEQITPROD,
                      I.IDORIGEMPROD
                    ) OP
                  WHERE N.CDFILIAL                = :P_CDFILIAL
                  AND N.NRLANCTONF                = :P_NRLANCTONF
                  AND N.CDFILDEST                 = I.CDFILDEST
                  AND N.CDFILLANC                 = I.CDFILLANC
                  AND N.NRAUTOFORN                = I.NRAUTOFORN
                  AND N.CDMARCA                   = I.CDMARCA
                  AND N.CDPRODUTO                 = I.CDPRODUTO
                  AND N.DTPROGENTAF               = I.DTPROGENTAF
                  AND I.CDPRODUTO                 = P.CDPRODUTO
                  AND I.CDPRODUTO                 = OP.CDPRARVORIG
                  AND (I.IDBAIXITMAF NOT         IN ('2','3')
                  OR I.IDBAIXITMAF               IS NULL)
                  AND NVL(I.CDMARCAOL, I.CDMARCA) = OP.CDMARCA
                  UNION ALL
                  SELECT P.CDPRODUTO,
                    P.CDARVPROD,
                    P.NMPRODUTO,
                    0                                                                          AS QTSAIDOPLOG,
                    OP.QTITEMPROD                                                              AS QTPROGENTAF,
                    CUSTO_PRODUTO(:P_CDFILDEST, P.CDPRODUTO, :P_TIPOCUSTO, :P_DTPROC, SYSDATE) AS VRPREUNIAF,
                    OP.QTITEMPROD                                                              AS QTNFRELAFSAI,
                    NULL CDFILLANC,
                    NULL CDFILDEST,
                    OP.NRSEQITPROD AS NRAUTOFORN,
                    OP.CDMARCA,
                    SYSDATE AS DTPROGENTAF,
                    OP.VRUNITITEM,
                    ''  AS VRTOTAITEM,
                    '2' AS IDUTILITEM,
                    OP.NRSEQITPROD,
                    OP.IDORIGEMPROD
                  FROM PRODUTO P,
                    (SELECT R.CDPRARVORIG,
                      R.CDMARCA,
                      I.QTITEMPROD,
                      I.VRUNITITEM,
                      I.NRSEQITPROD,
                      I.IDORIGEMPROD
                    FROM ITEMPRODUTO I,
                      RELACPRODOL R
                    WHERE I.CDFILIAL = :P_CDFILIAL
                    AND I.NRLANCTONF = :P_NRLANCTONF
                    AND I.CDPRODUTO  = R.CDPRODARVOL
                    ) OP
                  WHERE P.CDPRODUTO = OP.CDPRARVORIG
                  AND (EXISTS
                    (SELECT 1
                    FROM NFRELACPEXOL
                    WHERE NFRELACPEXOL.CDFILDEST  = :P_CDFILDEST
                    AND NFRELACPEXOL.CDFILIAL     = :P_CDFILIAL
                    AND NFRELACPEXOL.NRLANCTONF   = :P_NRLANCTONF
                    AND NFRELACPEXOL.CDPRODUTO    = P.CDPRODUTO
                    AND NFRELACPEXOL.QTNFRELPEXOL = OP.QTITEMPROD
                    AND NFRELACPEXOL.NRSEQITPEOL  = OP.NRSEQITPROD
                    AND (NFRELACPEXOL.CDMARCA     = OP.CDMARCA)
                    AND (:P_IDUTORIGPROD          = 'N')
                    )
                  OR EXISTS
                    (SELECT 1
                    FROM NFRELACPEXOL
                    WHERE NFRELACPEXOL.CDFILDEST = :P_CDFILDEST
                    AND NFRELACPEXOL.CDFILIAL    = :P_CDFILIAL
                    AND NFRELACPEXOL.NRLANCTONF  = :P_NRLANCTONF
                    AND NFRELACPEXOL.CDPRODUTO   = P.CDPRODUTO
                    AND (NFRELACPEXOL.CDMARCA    = OP.CDMARCA)
                    AND (:P_IDUTORIGPROD         = 'S')
                    ))
                  )
                GROUP BY CDPRODUTO,
                  CDARVPROD,
                  NMPRODUTO,
                  VRPREUNIAF,
                  CDFILLANC,
                  CDFILDEST,
                  NRAUTOFORN,
                  CDMARCA,
                  DTPROGENTAF,
                  VRUNITITEM,
                  IDUTILITEM,
                  NRSEQITPROD,
                  IDORIGEMPROD
                ORDER BY NMPRODUTO";
                
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf,
                        "P_CDFILDEST" => $cdFildest,
                        "P_TIPOCUSTO" => $tipocusto,
                        "P_DTPROC" => $dtProc,
                        "P_IDUTORIGPROD" => $idutorigprod);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getProdFili($cdFilial, $cdProduto) {
        $sql = "SELECT PRODFILI.IDPRODATIV, FILIAL.CDFILIAL, FILIAL.NMFILIAL
      
            FROM FILIAL INNER JOIN PRODFILI ON FILIAL.CDFILIAL    = PRODFILI.CDFILIAL 
        WHERE FILIAL.CDFILIAL      = :P_CDFILIAL
            AND PRODFILI.CDPRODUTO = :P_CDPRODUTO";
            
        $params = array("P_CDFILIAL"  => $cdFilial,
                        "P_CDPRODUTO" => $cdProduto);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getTranpNf($cdFilial, $nrLanctonf) {
        $sql = "SELECT IDTPIJURTRAN, NRINSJURTRAN, IDPGTOFRETE
            FROM NOTAFISCAL
           WHERE CDFILIAL   = :P_CDFILIAL
             AND NRLANCTONF = :P_NRLANCTONF";
        
        $params = array("P_CDFILIAL"   => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0];
    }
    
    public function getNrAcessoNfe($cdFilial, $nrLanctonf) {
        $sql = "SELECT NRACESSONFE
                    FROM NOTAFISCAL
                WHERE CDFILIAL = :P_CDFILIAL
                    AND NRLANCTONF = :P_NRLANCTONF";
         
        $params = array("P_CDFILIAL"   => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0]["NRACESSONFE"];   
    }
    
    public function setNrAcessoNfe($cdFilial, $nrLanctonf, $nrAcessoNfe, $dsNotaFisOrigOl) {
        $sql = "UPDATE NOTAFISCAL
                    SET DSNOTAFISORIGOL = :P_DSNOTAFISORIGOL,
                        NRACESSONFE     = :P_NRACESSONFE
                    WHERE CDFILIAL      = :P_CDFILIAL
                        AND NRLANCTONF  = :P_NRLANCTONF";
         
        $params = array("P_CDFILIAL"    => $cdFilial,
                        "P_NRLANCTONF"  => $nrLanctonf,
                        "P_NRACESSONFE" => $nrAcessoNfe,
                        "P_DSNOTAFISORIGOL" => $dsNotaFisOrigOl);
        $query = $this->connection->prepare($sql);
        $query->execute($params);   
    }
    
    public function getSugRegAux($cdfilirepl, $nrlancrepl) {
        $sql = "SELECT IE.IDSUGREGSTENTR, IE.CDENCARGOST
          FROM NOTAFISCAL NF INNER JOIN INSCRESTAD IE ON NF.CDEMPRESA = IE.CDEMPRESA
               AND NF.CDINSCESTA    = IE.CDINSCESTA
               AND IE.IDSUGREGSTENTR <> 'S'
      WHERE NF.CDFILIAL   = :P_CDFILIREPL
           AND NF.NRLANCTONF = :P_NRLANCREPL";
           
        $params = array("P_CDFILIREPL"   => $cdfilirepl,
                        "P_NRLANCREPL"   => $nrlancrepl);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();  
    }
    
    public function getSugRegEntr($cdFiliOrig, $nrLancOrig, $nrseqitprod){
        $sql = "SELECT SUM(NVL(II.VRIMPOSTOIT, 0))/IP.QTITEMPROD AS VRIMPOSTO
                FROM ITEMPRODUTO IP
                INNER JOIN ITEMPROIMPOS II
                ON IP.CDFILIAL     = II.CDFILIAL
                AND IP.NRLANCTONF  = II.NRLANCTONF
                AND IP.NRSEQITPROD = II.NRSEQITPROD
                INNER JOIN IMPOSTO I
                ON II.CDIMPOSTO    = I.CDIMPOSTO
                WHERE IP.CDFILIAL  = :P_CDFILIORIG
                AND IP.NRLANCTONF  = :P_NRLANCORIG
                AND IP.NRSEQITPROD = :P_NRSEQITPROD
                AND I.CDIMPOSTONFE = '80'
                GROUP BY IP.QTITEMPROD";
                
        $params = array("P_CDFILIORIG"   => $cdFiliOrig,
                        "P_NRLANCORIG"   => $nrLancOrig,
                        "P_NRSEQITPROD"  => $nrseqitprod);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();        
    }
    
    public function getQtItemNota($cdFilial, $nrLanctonf, $cdProduto, $cdMarca) {
        $sql = "SELECT VRTOTAITEM, QTITEMPROD
                  FROM ITEMPRODUTO, RELACPRODOL R
                  WHERE ITEMPRODUTO.CDFILIAL   = :P_CDFILIAL
                    AND ITEMPRODUTO.NRLANCTONF = :P_NRLANCTONF
                    AND ITEMPRODUTO.CDPRODUTO  = R.CDPRODARVOL
                    AND R.CDPRARVORIG          = :P_CDPRODUTO
                    AND R.CDMARCA              = :P_CDMARCA";
        
        $params = array("P_CDFILIAL"   => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf,
                        "P_CDPRODUTO"  => $cdProduto,
                        "P_CDMARCA"    => $cdMarca);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();        
    }
    
    public function getNfRelacAf($cdFilDest, $cdFilLanc, $nrLanctonf, $nrAutoForn, $cdMarca, $cdProduto, $dtProgentAf) {
        $sql = "SELECT NRLANCTONF
                  FROM NFRELACAF
                  WHERE CDFILIAL    = :P_CDFILIAL    AND
                        NRLANCTONF  = :P_NRLANCTONF  AND
                        CDFILDEST   = :P_CDFILDEST   AND
                        CDFILLANC   = :P_CDFILLANC   AND
                        NRAUTOFORN  = :P_NRAUTOFORN  AND
                        CDMARCA     = :P_CDMARCA     AND
                        CDPRODUTO   = :P_CDPRODUTO   AND
                        DTPROGENTAF = :P_DTPROGENTAF";
                        
        $params = array("P_CDFILIAL"    => $cdFilDest,
                        "P_NRLANCTONF"  => $nrLanctonf,
                        "P_CDFILDEST"   => $cdFilDest,
                        "P_CDFILLANC"   => $cdFilLanc,
                        "P_NRAUTOFORN"  => $nrAutoForn,
                        "P_CDMARCA"     => $cdMarca,
                        "P_CDPRODUTO"   => $cdProduto,
                        "P_DTPROGENTAF" => $dtProgentAf);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();   
    }
    
    public function insereNfRelacAf($cdFilial, $cdFilLanc, $nrLanctonf, $cdFilDest, $nrAutoForn, $cdProduto, $cdMarca, $dtProgentAf, $qtNfRelacAf, $vrNfRelac, $nrOrg) {
        $sql = "INSERT INTO NFRELACAF
              (
                CDFILIAL,
                CDFILLANC,
                NRLANCTONF,
                CDFILDEST,
                NRAUTOFORN,
                CDPRODUTO,
                CDMARCA,
                DTPROGENTAF,
                QTNFRELACAF,
                VRNFRELACAF,
                NRORG
              )
              VALUES
              (
                :CDFILIAL,
                :CDFILLANC,
                :NRLANCTONF,
                :CDFILDEST,
                :NRAUTOFORN,
                :CDPRODUTO,
                :CDMARCA,
                :DTPROGENTAF,
                :QTNFRELACAF,
                :VRNFRELACAF,
                :NRORG
              )";
        
         $params = array("CDFILIAL"    => $cdFilial,
                        "CDFILLANC"    => $cdFilLanc,
                        "NRLANCTONF"   => $nrLanctonf,
                        "CDFILDEST"    => $cdFilDest,
                        "NRAUTOFORN"   => $nrAutoForn,
                        "CDPRODUTO"    => $cdProduto,
                        "CDMARCA"      => $cdMarca,
                        "DTPROGENTAF"  => $dtProgentAf,
                        "QTNFRELACAF"  => $qtNfRelacAf, 
                        "VRNFRELACAF"  => $vrNfRelac,
                        "NRORG"        => $nrOrg);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function itBaixaAf($cdFilDest, $cdFilLanc, $nrAutoForn, $cdMarca, $cdProduto, $dtProgentAf) {
        $sql = "UPDATE ITEMAUTF
              SET    IDBAIXITMAF   = '2'
              WHERE CDFILDEST   = :CDFILDEST
                AND CDFILLANC   = :CDFILLANC
                AND NRAUTOFORN  = :NRAUTOFORN
                AND CDMARCA     = :CDMARCA
                AND CDPRODUTO   = :CDPRODUTO
                AND DTPROGENTAF = :DTPROGENTAF";
                
        $params = array("CDFILDEST"    => $cdFilDest,
                        "CDFILLANC"    => $cdFilLanc,
                        "NRAUTOFORN"   => $nrAutoForn,
                        "CDMARCA"      => $cdMarca,
                        "CDPRODUTO"    => $cdProduto,
                        "DTPROGENTAF"  => $dtProgentAf);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function baixaAf($cdFilDest, $cdFilLanc, $nrPedexOl) {
        $sql = "UPDATE AUTOFORNE
                  SET    IDBAIXAAF   = '2'
                  WHERE CDFILDEST    = :CDFILDEST
                    AND CDFILLANC    = :CDFILLANC
                    AND NRAUTOFORN   = :NRPEDEXOL";
        
        $params = array("CDFILDEST"    => $cdFilDest,
                        "CDFILLANC"    => $cdFilLanc,
                        "NRPEDEXOL"    => $nrPedexOl);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function relacNfOl($cdFilial, $nrLanctonf, $cdProduto, $cdMarca) {
        $sql = "SELECT CDFILDEST,
                 CDFILLANC,
                 NRPEDEXOL,
                 CDMARCA,
                 CDPRODUTO,
                 DTPROGENPEOL
            FROM NFRELACPEXOL
           WHERE CDFILIAL     = :P_CDFILIAL
             AND NRLANCTONF   = :P_NRLANCTONF
             AND CDPRODUTO    = :P_CDPRODUTO
             AND CDMARCA      = :P_CDMARCA";
             
        $params = array("P_CDFILIAL"    => $cdFilial,
                        "P_NRLANCTONF"  => $nrLanctonf,
                        "P_CDPRODUTO"   => $cdProduto,
                        "P_CDMARCA"     => $cdMarca);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();   
    }
    
    public function relacNfOlProd($cdFilial, $nrLanctonf, $cdFilDest, $cdFilLanc, $nrPedexOl, $cdMarca, $cdProduto, $dtProgenpeol) {
        $sql = "SELECT NRLANCTONF
            FROM NFRELACPEXOL
            WHERE CDFILIAL   = :P_CDFILIAL  AND
                NRLANCTONF   = :P_NRLANCTONF  AND
                CDFILDEST    = :P_CDFILDEST   AND
                CDFILLANC    = :P_CDFILLANC   AND
                NRPEDEXOL    = :P_NRPEDEXOL   AND
                CDMARCA      = :P_CDMARCA     AND
                CDPRODUTO    = :P_CDPRODUTO   AND
                DTPROGENPEOL = :P_DTPROGENPEOL";
                
        $params = array("P_CDFILIAL"        => $cdFilial,
                        "P_NRLANCTONF"      => $nrLanctonf,
                        "P_CDFILDEST"       => $cdFilDest,
                        "P_CDFILLANC"       => $cdFilLanc,
                        "P_NRPEDEXOL"       => $nrPedexOl,
                        "P_CDMARCA"         => $cdMarca,
                        "P_CDPRODUTO"       => $cdProduto,
                        "P_DTPROGENPEOL"    => $dtProgenpeol);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();   
    }
    
    public function insereNfRelacOlProd($cdFilial, $cdFilLanc, $nrLanctonf, $cdFilDest, $nrPedexOl, $cdProduto, $cdMarca, $dtProgenpeol, $qtNfrelpexol, $vrNfrelpexol, $nrSeqitpeol, $nrOrg) {
        $sql = "INSERT INTO NFRELACPEXOL
              (CDFILIAL, CDFILLANC, NRLANCTONF, CDFILDEST,
               NRPEDEXOL, CDPRODUTO, CDMARCA,
               DTPROGENPEOL, QTNFRELPEXOL, VRNFRELPEXOL, NRSEQITPEOL, NRORG)
              VALUES
              (:CDFILIAL, :CDFILLANC, :NRLANCTONF, :CDFILDEST,
               :NRPEDEXOL, :CDPRODUTO, :CDMARCA, :DTPROGENPEOL,
               :QTNFRELPEXOL, :VRNFRELPEXOL, :NRSEQITPEOL, :NRORG)"; 
        
        $params = array("CDFILIAL"        => $cdFilial,
                        "CDFILLANC"       => $cdFilLanc,
                        "NRLANCTONF"      => $nrLanctonf,
                        "CDFILDEST"       => $cdFilDest,
                        "NRPEDEXOL"       => $nrPedexOl,
                        "CDPRODUTO"       => $cdProduto,
                        "CDMARCA"         => $cdMarca,
                        "DTPROGENPEOL"    => $dtProgenpeol,
                        "QTNFRELPEXOL"    => $qtNfrelpexol,
                        "VRNFRELPEXOL"    => $vrNfrelpexol,
                        "NRSEQITPEOL"     => $nrSeqitpeol,
                        "NRORG"           => $nrOrg);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function updateNfRelacOlProd($cdFilial, $cdFilLanc, $nrLanctonf, $cdFildest, $nrPedexOl, $cdProduto, $cdMarca, $dtProgenpeol) {
        $sql = "UPDATE NFRELACPEXOL
                SET IDENTRADAPEDOL = 'S'
                WHERE CDFILIAL     = :CDFILIAL
                    AND NRLANCTONF   = :NRLANCTONF
                    AND CDFILDEST    = :CDFILDEST
                    AND CDFILLANC    = :CDFILLANC
                    AND NRPEDEXOL    = :NRPEDEXOL
                    AND CDMARCA      = :CDMARCA
                    AND CDPRODUTO    = :CDPRODUTO
                    AND DTPROGENPEOL = :DTPROGENPEOL";
        
        $params = array("CDFILIAL"        => $cdFilial,
                        "NRLANCTONF"      => $nrLanctonf,
                        "CDFILLANC"       => $cdFilLanc,
                        "CDFILDEST"       => $cdFilDest,
                        "NRPEDEXOL"       => $nrPedexOl,
                        "CDMARCA"         => $cdMarca,
                        "CDPRODUTO"       => $cdProduto,
                        "DTPROGENPEOL"    => $dtProgenpeol);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function baixaItemOl($cdFilDest, $cdFilLanc, $nrPedexOl, $cdMarca, $cdProduto, $dtProgenpeol) {
        $sql = "UPDATE ITEMPEDEXOL
                SET IDBAIXENPEOL = IDBAIXAOLSAI
                WHERE CDFILDEST    = :CDFILDEST    
                  AND CDFILLANC    = :CDFILLANC   
                  AND NRPEDEXOL    = :NRPEDEXOL   
                  AND CDMARCA      = :CDMARCA     
                  AND CDPRODUTO    = :CDPRODUTO   
                  AND DTPROGENPEOL = :DTPROGENPEOL";
        
        $params = array("CDFILDEST"       => $cdFilDest,
                        "CDFILLANC"       => $cdFilLanc,
                        "NRPEDEXOL"       => $nrPedexOl,
                        "CDMARCA"         => $cdMarca,
                        "CDPRODUTO"       => $cdProduto,
                        "DTPROGENPEOL"    => $dtProgenpeol);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function baixaPedOl($cdFilDest, $cdFilLanc, $nrPedexOl) {
        $sql = "UPDATE PEDIDOEXOL
                SET IDBAIXEXOL = IDBAIXEXSAI
                WHERE CDFILDEST    = :CDFILDEST
                  AND CDFILLANC    = :CDFILLANC
                  AND NRPEDEXOL    = :NRPEDEXOL";
        
        $params = array("CDFILDEST"       => $cdFilDest,
                        "CDFILLANC"       => $cdFilLanc,
                        "NRPEDEXOL"       => $nrPedexOl);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function getEndeFili($cdFilial) {
        $sql = "SELECT CDPAIS,
                  SGESTADO ,
                  CDMUNICIPIO
                FROM ENDEFILI
                WHERE CDFILIAL             = :P_CDFILIAL
                AND (NVL(IDTPENDEFILI, 'P') = 'P')";
                    
        $params = array("P_CDFILIAL" => $cdFilial);
                    
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();   
    }
    
    public function getIncidencia($inciTemp) {
        $sql = "SELECT CDIMPOTEMP,
                  MAX(CDFISCTEMP)             AS CDFISCTEMP,
                  MAX(IDTRATIMPTMP)           AS IDTRATIMPTMP,
                  MAX(IDCONSISTENT)           AS IDCONSISTENT,
                  MAX(NVL(IDUTMUNIORIG, 'N')) AS IDUTMUNIORIG,
                  MAX(IDIMPORECUP)            AS IDIMPORECUP,
                  MAX(NVL(IDPREIMPENTR, 'N')) AS IDPREIMPENTR,
                  MAX(IDORGARRECAD)           AS IDORGARRECAD
                FROM INCITEMP IT,
                  IMPOSTO IP
                WHERE (IT.NRINCITEMP = :P_INCITEMP)
                AND (IP.CDIMPOSTO    = IT.CDIMPOTEMP)
                AND (IP.IDPRODNOTA   = 'P')
                GROUP BY CDIMPOTEMP";
                
        $params = array("P_INCITEMP" => $inciTemp);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();   
    }
    
    public function getAliqTemp($inicTemp) {
        $sql = "SELECT NVL(MAX(NRALIQTEMP),0) AS NRALIQTEMP,
                  NVL(MAX(VRPARDEDTMP ),0)    AS VRPARDEDTMP,
                  NVL(MAX(VRPREDBCTMP),0)     AS VRPREDBCTMP,
                  NVL(MAX(VRALIQUTMP),0)      AS VRALIQUTMP,
                  NVL(MAX(VRPBCSTTMP),0)      AS VRPBCSTTMP,
                  NVL(MAX(IDTRIMPSTTMP), '0') AS IDTRIMPSTTMP
                FROM ALIQTEMP
                WHERE (NRALIQTEMP = :P_ALIQTEMP)";
        
        $params = array("P_ALIQTEMP" => $inicTemp);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0];  
    }
    
    public function insereTrabProImpos($cdFilial, $nrLanctonf, $nrSeqItProd, $cdImpoTemp, $incidencia, $perdbCalc, $pardedTmp, $contabCalc, $vrAliqimpoit, $vrImposto, $organizacao) {

        $sql = "INSERT
                INTO TRABITPROIMPOS
                  (
                    CDFILIMPOIT,
                    NRLANCIMPOIT,
                    NRSEQIMPOIT,
                    CDIMPOSTOIT,
                    NRSEQITPRO,
                    CDFISCIMPOIT,
                    CDSTRIBIMPOIT,
                    CDFOPERIMPOIT,
                    CDSCFOPIMPOIT,
                    VRALIQIMPOIT,
                    VRREDBCIMPOIT,
                    VRPDEDIMPOIT,
                    VRCONTIMPOIT,
                    VRBCALCIMPOIT,
                    VRIMPOSIT,
                    IDERRIMPOIT,
                    IDAVISIMPOIT,
                    IDVALORINFO,
                    NRORG
                  )
                  VALUES
                  (
                    :P_FILIAL,
                    :P_LANCTONF,
                    :P_NRSEQITPROD,
                    :P_CDIMPOTEMP,
                    '1',
                    :P_INCIDENCIA,
                    '',
                    '',
                    '',
                    :P_VRALIQIMPOIT,
                    :P_PERDBCALC,
                    :P_PARDEDTMP,
                    :P_CONTABCALC,
                    :P_CONTABCALC,
                    :P_VRIMPOSTO,
                    '00000',
                    '00000',
                    'N',
                    :P_NRORG
                  )";
        
        $params = array("P_FILIAL"          => $cdFilial,
                        "P_LANCTONF"        => $nrLanctonf,
                        "P_NRSEQITPROD"     => $nrSeqItProd,
                        "P_CDIMPOTEMP"      => $cdImpoTemp,
                        "P_INCIDENCIA"      => $incidencia,
                        "P_VRALIQIMPOIT"    => $vrAliqimpoit,
                        "P_PERDBCALC"       => $perdbCalc,
                        "P_PARDEDTMP"       => $pardedTmp,
                        "P_CONTABCALC"      => $contabCalc,
                        "P_VRIMPOSTO"       => $vrImposto,
                        "P_NRORG"           => $organizacao);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function insereTrabImpoNfTot($cdFiliImpoIt, $nrLancImpoIt, $cdImpostoIt, $vrImpostoIt, $errosTot, $avisoTot, $vrBCalImpTot, $nrOrg) {
        $sql = "INSERT
                INTO TRABIMPOSNFTOT
                  (
                    CDFILIMPTOT,
                    NRLANCIMPTOT,
                    CDIMPOSTOT,
                    VRIMPOSTOT,
                    IDERROSTOT,
                    IDAVISOSTOT,
                    VRBCALIMPTOT, 
                    NRORG
                  )
                  VALUES
                  (
                    :CDFILIMPTOT,
                    :NRLANCIMPTOT,
                    :CDIMPOSTOT,
                    :VRIMPOSTOT,
                    :IDERROSTOT,
                    :IDAVISOSTOT,
                    :VRBCALIMPTOT,
                    :NRORG
                  )";
                  
        $params = array("CDFILIMPTOT" => $cdFiliImpoIt,
                    "NRLANCIMPTOT" => $nrLancImpoIt,
                    "CDIMPOSTOT" => $cdImpostoIt,
                    "VRIMPOSTOT" => $vrImpostoIt,
                    "IDERROSTOT" => $errosTot,
                    "IDAVISOSTOT" => $avisoTot,
                    "VRBCALIMPTOT" => $vrBCalImpTot,
                    "NRORG" => $nrOrg);
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function updateTrabImpoNfTot($cdFiliImpoIt, $nrLancImpoIt, $cdImpostoIt, $vrImpostoIt, $errosTot, $avisoTot, $vrBCalImpTot, $nrOrg) {
        $sql = "UPDATE TRABIMPOSNFTOT
                SET VRIMPOSTOT    = :VRIMPOSTOT,
                  IDERROSTOT      = :IDERROSTOT,
                  IDAVISOSTOT     = :IDAVISOSTOT,
                  VRBCALIMPTOT    = :VRBCALIMPTOT
                WHERE CDFILIMPTOT = :OLD_CDFILIMPTOT
                AND NRLANCIMPTOT  = :OLD_NRLANCIMPTOT
                AND CDIMPOSTOT    = :OLD_CDIMPOSTOT";
                  
        $params = array("VRIMPOSTOT" => $vrImpostoIt,
                    "IDERROSTOT" => $errosTot,
                    "IDAVISOSTOT" => $avisoTot,
                    "VRBCALIMPTOT" => $vrBCalImpTot,
                    "OLD_CDFILIMPTOT" => $cdFiliImpoIt,
                    "OLD_NRLANCIMPTOT" => $nrLancImpoIt,
                    "OLD_CDIMPOSTOT" => $cdImpostoIt);
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function deleteAliqTemp($aliqTemp) {
        $sql = "DELETE ALIQTEMP WHERE NRALIQTEMP = :P_ALIQTEMP";
        
        $params = array("P_ALIQTEMP" => $aliqTemp); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function deleteInicTemp($iniciTemp) {
        $sql = "DELETE INCITEMP WHERE NRINCITEMP = :P_INCITEMP";
        
        $params = array("P_INCITEMP" => $iniciTemp); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function updateItAfRelac($cdFilDest, $cdFilLanc, $nrPedxOl, $cdProduto, $cdMarca, $dtProgenpeOl) {
        $sql = "UPDATE ITEMAUTF
            SET IDITMSEPARADO = 'N'
            WHERE CDFILDEST   = :P_CDFILDEST
            AND CDFILLANC     = :P_CDFILLANC
            AND NRAUTOFORN    = :P_NRPEDEXOL
            AND CDPRODUTO     = :P_CDPRODUTO
            AND CDMARCA       = :P_CDMARCA
            AND DTPROGENTAF   = :P_DTPROGENPEOL";
        
        $params = array("P_CDFILDEST"    => $cdFilDest,
                        "P_CDFILLANC"    => $cdFilLanc,
                        "P_NRPEDEXOL"     => $nrPedxOl,
                        "P_CDPRODUTO"    => $cdProduto,
                        "P_CDMARCA"      => $cdMarca,
                        "P_DTPROGENPEOL" => $dtProgenpeOl); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);    
    }
    
    public function deleteRateioNf($cdFilial, $nrLanctonf) {
        $sql = "DELETE RATEIONF WHERE CDFILIAL   = :P_CDFILIAL 
                AND NRLANCTONF = :P_NRLANCTONF";
                
        $params = array("P_CDFILIAL"      => $cdFilial,
                        "P_NRLANCTONF"    => $nrLanctonf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);    
    }
    
    public function getNotaFiscalRateio($cdFilial, $nrLanctonf) {
        $sql = "SELECT CDFILIRECE,
                  CDTIPOOPER,
                  CDFILIEMIT,
                  DTEMISSAO,
                  DTENTRSAID,
                  NVL(IDORIGDESTNF,'F')      AS IDORIGDESTNF,
                  NVL(IDNFGERADAVIAXML, 'N') AS IDNFGERADAVIAXML
                FROM NOTAFISCAL
                WHERE CDFILIAL = :P_CDFILIAL
                AND NRLANCTONF = :P_NRLANCTONF";
        
        $params = array("P_CDFILIAL"      => $cdFilial,
                        "P_NRLANCTONF"    => $nrLanctonf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);    
        
        return $query->fetchAll()[0];  
    }
    
    public function getConsContaRateio($idEntrSaid, $cdTipoOper) {
        $sql = "SELECT NVL(IDCONSCTBRAT, 'N') AS IDCONSCTBRAT
                FROM TIPOOPERAC
                WHERE IDENTRSAIDOP = :P_IDENTRSAIDOP
                AND CDTIPOOPER     = :P_CDTIPOOPER";
                
        $params = array("P_IDENTRSAIDOP"  => $idEntrSaid,
                        "P_CDTIPOOPER"    => $cdTipoOper); 
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);    
        
        return $query->fetchAll()[0];  
    }
    
    public function getContaPagar($cdFilial, $nrLanctonf) {
        $sql = "SELECT MAX(CDTPCTPAGAR) AS CDTPCTPAGAR
                FROM CONTAPAGAR
                WHERE CDFILIAL   = :P_CDFILIAL AND
                    NRLANCTONF = :P_NRLANCTONF";
                    
        $params = array("P_CDFILIAL"      => $cdFilial,
                        "P_NRLANCTONF"    => $nrLanctonf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
                 
        return $query->fetchAll();     
    }
    
    public function getTpContaNfEntr($cdFilial, $nrLanctonf) {
        $sql = "SELECT TR.CDTPCTPAGAR
                FROM
                  (SELECT MAX(CDARVPROD) AS CDARVPROD
                  FROM ITEMPRODUTO I,
                    PRODUTO P
                  WHERE CDFILIAL  = :P_CDFILIAL
                  AND NRLANCTONF  = :P_NRLANCTONF
                  AND I.CDPRODUTO = P.CDPRODUTO
                  GROUP BY VRTOTAITEM
                  HAVING VRTOTAITEM =
                    (SELECT MAX(VRTOTAITEM)
                    FROM ITEMPRODUTO
                    WHERE CDFILIAL = :P_CDFILIAL
                    AND NRLANCTONF = :P_NRLANCTONF
                    )
                  ) IT,
                  PRODUTO PR ,
                  TIPOCTPAGAR TR
                WHERE TR.CDTPCTPAGAR = PR.CDTPCTPAGAR
                AND PR.CDARVPROD     =
                  (SELECT MAX(P.CDARVPROD)
                  FROM TIPOCTRECEPROD C,
                    PRODUTO P
                  WHERE C.CDPRODUTO                            = P.CDPRODUTO
                  AND (INSTR(IT.CDARVPROD, RTRIM(P.CDARVPROD)) = 1)
                  )";
                  
        $params = array("P_CDFILIAL"      => $cdFilial,
                        "P_NRLANCTONF"    => $nrLanctonf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
                 
        return $query->fetchAll()[0];     
    }
    
    public function getItemProduto($cdFilial, $nrLanctonf) {
        $sql = "SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD, VRCONTITEM, DSPRODEMIS
                FROM ITEMPRODUTO
                WHERE CDFILIAL   = :P_CDFILIAL AND
                    NRLANCTONF   = :P_NRLANCTONF";
                    
        $params = array("P_CDFILIAL"      => $cdFilial,
                        "P_NRLANCTONF"    => $nrLanctonf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
                 
        return $query->fetchAll(); 
    }
    
    public function getRatTpCtp($cdTpCtPagar) {
        $sql = "SELECT CDCENTCUST,
                  VRPERATTPCTP,
                  CDFILIAL
                FROM RATTPCTP
                WHERE CDTPCTPAGAR = :P_CDTPCTPAGAR";
                
        $params = array("P_CDTPCTPAGAR" => $cdTpCtPagar); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
                 
        return $query->fetchAll(); 
    }
    
    public function getRateioProd($cdFilial, $nrLanctonf, $nrSeqItProd, $cdFilCentCust, $cdCentCustNf) {
        $sql = "SELECT CDFILIAL
                FROM RATEIONF
                WHERE CDFILIAL  = :P_CDFILIAL
                AND NRLANCTONF  = :P_NRLANCTONF
                AND NRSEQITPROD = :P_NRSEQITPROD
                AND CDFILICCUST = :P_CDFILICCUST
                AND CDCENTCUSNF = :P_CDCENTCUSNF";
        
        $params = array("P_CDFILIAL"      => $cdFilial,
                        "P_NRLANCTONF"    => $nrLanctonf,
                        "P_NRSEQITPROD"   => $nrSeqItProd,
                        "P_CDFILICCUST"   => $cdFilCentCust,
                        "P_CDCENTCUSNF"   => $cdCentCustNf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
        
        return $query->fetchAll();         
    }
    
    public function insereRateioProd($cdFilial, $nrLanctonf, $nrSeqItProd, $cdFiliCcust, $vrRateNf, $cdCentcusNf, $vrPerRat, $nrOrg){
        $sql = "INSERT
                INTO RATEIONF
                  (
                    CDFILIAL,
                    NRLANCTONF,
                    NRSEQITPROD,
                    CDFILICCUST,
                    VRRATENF,
                    CDCENTCUSNF,
                    VRPERRAT,
                    NRORG
                  )
                  VALUES
                  (
                    :P_CDFILIAL,
                    :P_NRLANCTONF,
                    :P_NRSEQITPROD,
                    :P_CDFILICCUST,
                    :P_VRRATENF,
                    :P_CDCENTCUSNF,
                    :P_VRPERRAT,
                    :P_NRORG
                  )";
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf,
                        "P_NRSEQITPROD" => $nrSeqItProd,
                        "P_CDFILICCUST" => $cdFiliCcust,
                        "P_VRRATENF" => $vrRateNf,
                        "P_CDCENTCUSNF" => $cdCentcusNf,
                        "P_VRPERRAT" => $vrPerRat,
                        "P_NRORG" => $nrOrg); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
    }
    
    public function updateRateioProd($cdFilial, $nrLanctonf, $nrSeqItProd, $cdFiliCcust, $cdCentcusNf, $vrRateNf, $vrPerRat) {
        $sql = "UPDATE RATEIONF
                SET VRRATENF    = VRRATENF + :P_VRRATENF,
                  VRPERRAT      = VRPERRAT + :P_VRPERRAT
                WHERE CDFILIAL  = :P_CDFILIAL
                AND NRLANCTONF  = :P_NRLANCTONF
                AND NRSEQITPROD = :P_NRSEQITPROD
                AND CDFILICCUST = :P_CDFILICCUST
                AND CDCENTCUSNF = :P_CDCENTCUSNF";
        
        $params = array("P_VRRATENF" => $vrRateNf, 
                        "P_VRPERRAT" => $vrPerRat, 
                        "P_CDFILIAL" => $cdFilial, 
                        "P_NRLANCTONF" => $nrLanctonf, 
                        "P_NRSEQITPROD" => $nrSeqItProd, 
                        "P_CDFILICCUST" => $cdFiliCcust, 
                        "P_CDCENTCUSNF" => $cdCentcusNf); 
                 
        $query = $this->connection->prepare($sql);
        $query->execute($params);                
    }
    
    public function insereRateioNfeEntr($cdFilial, $nrLanctonf, $cdFiliRece) {
        $sql = "INSERT
                INTO RATEIONF
                  (
                    CDFILIAL,
                    NRLANCTONF,
                    NRSEQITPROD,
                    CDFILICCUST,
                    VRRATENF,
                    CDCENTCUSNF,
                    VRPERRAT
                  )
                  (SELECT I.CDFILIAL,
                      I.NRLANCTONF,
                      I.NRSEQITPROD,
                      N.CDFILIRECE,
                      I.VRCONTITEM,
                      NVL(NVL(NVL(PF.CDCCUSTENTRF,P.CDCCUSTENTR),F.CDCENTCUST) ,E.CDCENTCUST) CDCENTCUST,
                      100 AS VRPERRAT
                    FROM NOTAFISCAL N,
                      ITEMPRODUTO I,
                      PRODFILI PF,
                      PRODUTO P,
                      EMPRESA E,
                      FILIAL F
                    WHERE N.CDFILIAL                                                              = :P_CDFILIAL
                    AND N.NRLANCTONF                                                              = :P_NRLANCTONF
                    AND I.CDFILIAL                                                                = :P_CDFILIAL
                    AND I.NRLANCTONF                                                              = :P_NRLANCTONF
                    AND I.CDPRODUTO                                                               = PF.CDPRODUTO(+)
                    AND PF.CDFILIAL(+)                                                            = NVL(I.CDFILIMOVI,:P_CDFILIRECE)
                    AND I.CDPRODUTO                                                               = P.CDPRODUTO
                    AND N.CDEMPRESA                                                               = E.CDEMPRESA
                    AND N.CDFILIRECE                                                              = F.CDFILIAL
                    AND NVL(NVL(NVL(PF.CDCCUSTENTRF,P.CDCCUSTENTR), F.CDCENTCUST) ,E.CDCENTCUST) IS NOT NULL
                  )";
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf,
                        "P_CDFILIRECE" => $cdFiliRece);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
    }
    
    public function getDadosNf($cdFilial, $nrLanctonf) {
        $sql = "SELECT IDENTRSAIDOP,
                  CDTIPOOPER
                FROM NOTAFISCAL
                WHERE CDFILIAL = :P_CDFILIAL
                AND NRLANCTONF = :P_NRLANCTONF";
                
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll()[0];  
    }
    
    public function getImpostoObrigatorio($idEntrSaid, $cdTipoOper) {
        $sql = "SELECT I.CDIMPOSTO,
                  IM.IDPRODNOTA,
                  IM.SGIMPOSTO
                FROM IMPOBRIGTPOPER I,
                  IMPOSTO IM
                WHERE I.IDENTRSAIDOP = :P_IDENTRSAIDOP
                AND I.CDTIPOOPER     = :P_CDTIPOOPER
                AND IM.CDIMPOSTO     = I.CDIMPOSTO";
                
        $params = array("P_IDENTRSAIDOP" => $idEntrSaid,
                        "P_CDTIPOOPER" => $cdTipoOper);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll();  
    }
    
    public function getImpostoProdutos($cdFilial, $nrLanctonf, $cdImposto) {
        $sql = "SELECT A.CDPRODUTO,
                  A.CDFILIAL,
                  P.CDARVPROD,
                  P.NMPRODUTO
                FROM ITEMPRODUTO A,
                  PRODUTO P
                WHERE A.CDFILIAL = :P_CDFILIAL
                AND A.NRLANCTONF = :P_NRLANCTONF
                AND A.CDPRODUTO  = P.CDPRODUTO
                AND NOT EXISTS
                  (SELECT CDFILIAL
                  FROM ITEMPROIMPOS I
                  WHERE I.CDFILIAL  = A.CDFILIAL
                  AND I.NRLANCTONF  = A.NRLANCTONF
                  AND I.NRSEQITPROD = A.NRSEQITPROD
                  AND I.CDIMPOSTO   = :P_CDIMPOSTO
                  )";
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf,
                        "P_CDIMPOSTO" => $cdImposto);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        return $query->fetchAll();
    }
    
    public function getImpostoNota($cdFilial, $nrLanctonf, $cdImposto) {
        $sql = "SELECT MAX(CDFILIAL) AS CDFILIAL
                FROM IMPOSTONF
                WHERE CDFILIAL = :P_CDFILIAL
                AND NRLANCTONF = :P_NRLANCTONF
                AND CDIMPOSTO  = :P_CDIMPOSTO";
                
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf,
                        "P_CDIMPOSTO" => $cdImposto);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll();
    }
    
    public function getQtItemNotaEntrada($cdFilial, $nrLanctonf) {
        $sql = "SELECT NVL(COUNT(*), 0) CONTADOR_ENTRADA
               FROM NOTAFISCAL N, ITEMPRODUTO I
               WHERE N.CDFILIAL     = :P_CDFILIAL
                 AND N.NRLANCTONF   = :P_NRLANCTONF
                 AND N.CDFILIAL     = I.CDFILIAL
                 AND N.NRLANCTONF   = I.NRLANCTONF";
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll()[0]["CONTADOR_ENTRADA"];
    }
    
    public function getQtItemNotaSaida($cdFilial, $nrLanctonf) {
        $sql = "SELECT NVL(COUNT(*), 0) CONTADOR_SAIDA
                FROM NOTAFISCAL N, ITEMPRODUTO I
               WHERE N.CDFILIAL    = :P_CDFILIAL
                 AND N.NRLANCTONF  = :P_NRLANCTONF
                 AND N.CDFILIAL    = I.CDFILIAL
                 AND N.NRLANCTONF  = I.NRLANCTONF";
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll()[0]["CONTADOR_SAIDA"];
    }
    
    public function getValorNotaEntrada($cdFilial, $nrLanctonf) {
        $sql = "SELECT N.VRNOTAFISC, N.DSNOTAFISORIGOL
               FROM NOTAFISCAL N
               WHERE N.CDFILIAL     = :P_CDFILIAL
                 AND N.NRLANCTONF   = :P_NRLANCTONF
                 AND N.DSNOTAFISORIGOL IS NOT NULL"; 
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
                
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll()[0]["VRNOTAFISC"];
    }
    
    public function getValorNotaSaida($cdFilial, $nrLanctonf) {
        $sql = "SELECT N.VRNOTAFISC
                FROM NOTAFISCAL N
               WHERE N.CDFILIAL    = :P_CDFILIAL
                 AND N.NRLANCTONF  = :P_NRLANCTONF"; 
        
        $params = array("P_CDFILIAL" => $cdFilial,
                        "P_NRLANCTONF" => $nrLanctonf);
                
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll()[0]["VRNOTAFISC"];
    }
    
    public function updateNrAutoFornProd($nrAutoForn, $cdFilial, $nrLanctonf) {
        $sql = "UPDATE ITEMPRODUTO
                    SET NRAUTOFORN      = :P_NRAUTOFORN
                    WHERE CDFILIAL      = :P_CDFILIAL
                        AND NRLANCTONF  = :P_NRLANCTONF";
         
        $params = array("P_NRAUTOFORN"  => $nrAutoForn,
                        "P_CDFILIAL"    => $cdFilial,
                        "P_NRLANCTONF"  => $nrLanctonf);
                        
        $query = $this->connection->prepare($sql);
        $query->execute($params);   
    }
    
    public function getSerieEntr($cdSerie) {
        $sql = "SELECT CDSERIEENTR FROM SERIEENTR WHERE CDSERIEENTR = :P_CDSERIENTR";
        
        $params = array("P_CDSERIENTR" => $cdSerie);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params); 
        
        return $query->fetchAll();
    }
    
    public function verificaNotaSendoUtilizada($filial, $numero) {
        $sql = "SELECT CDFILIAL
                FROM NOTAFISCAL
                WHERE CDFILIRECE    = :P_CDFILIRECE
                AND IDENTRSAIDOP  = 'E' 
                AND NRNOTAFISC    = :P_NRNOTAFISC FOR UPDATE NOWAIT";
                
        $params = array(
            "P_NRNOTAFISC"        => $numero,
            "P_CDFILIRECE"          => $filial
        );
        
        try {
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            $result = $query->fetch();
            return false;
        }
        catch(\Exception $e) {
            return true;
        }
    }
}
